=======
Credits
=======

Owner
-----

* Henry Bell `@henrybell <https://github.com/henrybell>`_

Development Leads
-----------------

* James Routley `@jamesroutley <https://github.com/jamesroutley>`_
* Sean Rankine `@theseanything <https://github.com/theseanything>`_

Contributors
------------

* Olivier Van Goethem `@oliviervg1 <https://github.com/oliviervg1>`_
* Adrian Fernandez `@afdezl <https://github.com/afdezl>`_
* Luke Plausin `@lukeplausin <https://github.com/lukeplausin>`_
* Douglas Fraser `@douglasfraser <https://github.com/douglasfraser>`_
* Amy Bruce-Gardner `@amybg <https://github.com/amybg>`_
* Marius Galbinasu `@galbinasu <https://github.com/galbinasu>`_
* Matthew Taylor `@matalo33 <https://github.com/matalo33>`_
* Yvonne Beumer `@pinkeee <https://github.com/pinkieee>`_
* Max Eskenazi <max@eskenazi.net>
